@@ -1,7 +1,9 @@
 mod completion;
 mod editor;
 mod example;
+mod validate;
 
 pub use completion::run as completion;
 pub use editor::run as editor;
 pub use example::run as example;
+pub use validate::run as validate;
